Botones de uso común

Botones de uso común | TOC

Pequeña descripción de cada botoón.

| Texto en negrita.
| Texto en cursiva.
| Texto subrayado.
| Texto tachado.
| Alinear a la izquierda.
| Alinear al centro.
| Alinear a la derecha.
| Alinear justificado.
| Lista desordenada/lista por puntos.
| Lista ordenada/lista numerada
| Disminuir la sangría.
| Aumentar la sangría.
| Deshacer la última operación.
| Rehacer la última operación.
| Insertar un enlace, más información en insertar enlace.
| Quita el enlace al texto seleccionado.
| Insertar un imagen, más información en insertar imagen.
| Limpiar código, esta función es útil cuando copias el código de otra página.
| Muestra esta ventana de ayuda.
| Abre el editor de HTML.
| Inserta una nueva tabla de 2x2.
| Añade una fila encima.
| Añade una fila debajo.
| Elimina una fila.
| Añade una columna antes de la actual .
| Añade una columna después de la actual.
| Elimina la columna actual.
| Inserta un separador horizontal
| Elimina el formato de la selección.
| Subíndice.
| Superíndice.

Ir a: Lista de contenidos | Top